@@ -1,27 +1,27 @@
+mod sparkline;
 mod time_marker;
 mod timestamp_finder;
 
-use crate::timestamp_finder::TimestampFinder;
 use anyhow::*;
-use sparkline::*;
 use std::io::{prelude::*, BufReader};
 
-pub fn build_sparkline(timestamps: &[i64], length: usize) -> Result<String, anyhow::Error> {
+use crate::sparkline::sparkline;
+use crate::timestamp_finder::TimestampFinder;
+
+pub fn build_sparkline(timestamps: &[i64], length: usize) -> Result<String> {
     let timestamps_per_bucket = timestamp_frequency_distribution(timestamps, length);
     let (min, max) = (
         *timestamps_per_bucket.iter().min().unwrap() as f64,
         *timestamps_per_bucket.iter().max().unwrap() as f64,
     );
-    let sparky = select_sparkline(SparkThemeName::Classic);
-
     let sparkline = timestamps_per_bucket
         .iter()
-        .map(|count| sparky.spark(min, max, *count as f64).to_owned())
+        .map(|count| sparkline(min, max, *count as f64).to_owned())
         .collect();
     Ok(sparkline)
 }
 
-pub fn scan_for_timestamps<R>(reader: R, format: &str) -> Result<Vec<i64>, anyhow::Error>
+pub fn scan_for_timestamps<R>(reader: R, format: &str) -> Result<Vec<i64>>
 where
     R: Read,
 {
